## [1.1.0](https://github.com/ScrapeGraphAI/scrapebiblio/compare/v1.0.0...v1.1.0) (2024-10-18)


### Features

* update prompt ([407ebfd](https://github.com/ScrapeGraphAI/scrapebiblio/commit/407ebfda424888279229cee4ebcd6d616ee7af92))

## 1.0.0 (2024-10-07)


### Bug Fixes

* add semantic release ([ca8addc](https://github.com/ScrapeGraphAI/scrapebiblio/commit/ca8addc1b89a592bcb432e9900597830c6a9618f))
* reate README.MD ([803a9ea](https://github.com/ScrapeGraphAI/scrapebiblio/commit/803a9ea5aa03b688f8b9371a82bf8daf4732de7b))
* update readme ([1ed0886](https://github.com/ScrapeGraphAI/scrapebiblio/commit/1ed08867c1a7675b4344427fcf482f5e1f61a83f))


### chore

* **CI:** add release config file ([30cf434](https://github.com/ScrapeGraphAI/scrapebiblio/commit/30cf434297bca39e824b9fef1d31240cfe1d0094))
* **CI:** fix build issues ([e772e56](https://github.com/ScrapeGraphAI/scrapebiblio/commit/e772e5688b4fe7549297e91884b12caa9d9d371c))
* fix pyproject ([d32a922](https://github.com/ScrapeGraphAI/scrapebiblio/commit/d32a922bf6e4c1810298de341e76a7cd6d6ecb35))
